import {useState, useEffect} from 'react';
import Config from '../../config';
import "./promolistStyle.css";
import { NavLink } from 'react-router-dom';

export default function PromotionIndexComponent () {

    const [promoData, setPromoData] = useState([]);

    useEffect( () => {
        loadPromotions();
    }, [])

    const loadPromotions = async () => {
        const response = await fetch(`${Config.promotionsUrl}`);
        const data = await response.json();
        setPromoData(data);
    }

    const deletePromotion = (promoId) => {
        fetch(`${Config.promotionsUrl}/${promoId}`, {
            method: "DELETE",
        })
        .then(res => loadPromotions())
        .catch(err => console.log("error"))
    }

    return (
        <div>
            
            <div className="container flex-column d-flex justify-content-center">
                <div className="container mt-3 d-flex justify-content-between align-items-center">
                        <h1 className="promo-title"> Promotions</h1>
                        <NavLink className="add-navLink" to='/promos/new'><button className="btn btn-success">+ New Promotion</button></NavLink>
                    </div>
                    <table className="promo-index-list">
                        <thead className="promo-table-title">
                            <tr>
                            <th>
                                Promotion Id
                            </th>
                            <th>
                                Product SKU
                            </th>
                            <th>
                                Discount
                            </th>
                            <th>
                                Minimum Quanitity
                            </th>
                            <th className="row-width">

                            </th>
                            <th className="row-width">

                            </th >
                            </tr>
                        </thead>
                        <tbody>
                        {promoData.length > 0 ? promoData.map((promo, key) => {
                            return (
                            <tr key={key}>
                            <td>
                                {promo.promotionId}
                            </td>
                            <td>
                                {promo.productSku}
                            </td>
                            <td>
                                {promo.discountPercentage}%
                            </td>
                            <td>
                                {promo.minimumQuantity}
                            </td>
                            <td>
                                <NavLink className="edit-navLink"  to={{
                                    pathname: `/promos/${promo.promotionId}/update`,
                                    state: {promo}
                                    }}>
                                    <button className="btn-color btn btn-primary btn-sm">Update</button>
                                </NavLink>
                            </td>
                            <td>
                                <button className="btn btn-danger btn-sm" onClick={() => deletePromotion(promo.promotionId)}>Delete</button>
                            </td>
                            </tr>
                            )
                        }).reverse() : <p>no promotions found.</p>}
                        
                        </tbody>
                    </table>
                </div>
            </div>
    )
}
